'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var view = require('@codemirror/view');
var state = require('@codemirror/state');
var language = require('@codemirror/language');
var commands = require('@codemirror/commands');
var search = require('@codemirror/search');
var autocomplete = require('@codemirror/autocomplete');
var lint = require('@codemirror/lint');
var langMarkdown = require('@codemirror/lang-markdown');
var languageData = require('@codemirror/language-data');

const SthenoConfig = {
    extensions: [
        view.highlightSpecialChars(),
        commands.history(),
        view.drawSelection(),
        view.dropCursor(),
        state.EditorState.allowMultipleSelections.of(true),
        language.indentOnInput(),
        language.syntaxHighlighting(language.defaultHighlightStyle, { fallback: true }),
        language.bracketMatching(),
        autocomplete.closeBrackets(),
        autocomplete.autocompletion(),
        search.highlightSelectionMatches(),
        view.EditorView.lineWrapping,
        view.keymap.of([
            ...autocomplete.closeBracketsKeymap,
            ...commands.defaultKeymap,
            ...search.searchKeymap,
            ...commands.historyKeymap,
            ...language.foldKeymap,
            ...autocomplete.completionKeymap,
            ...lint.lintKeymap,
            commands.indentWithTab,
        ]),
        langMarkdown.markdown({ codeLanguages: languageData.languages, base: langMarkdown.markdownLanguage })
    ],
};

exports.SthenoConfig = SthenoConfig;
