import { highlightSpecialChars, drawSelection, dropCursor, EditorView, keymap } from '@codemirror/view';
import { EditorState } from '@codemirror/state';
import { indentOnInput, syntaxHighlighting, defaultHighlightStyle, bracketMatching, foldKeymap } from '@codemirror/language';
import { history, defaultKeymap, historyKeymap, indentWithTab } from '@codemirror/commands';
import { highlightSelectionMatches, searchKeymap } from '@codemirror/search';
import { closeBrackets, autocompletion, closeBracketsKeymap, completionKeymap } from '@codemirror/autocomplete';
import { lintKeymap } from '@codemirror/lint';
import { markdown, markdownLanguage } from '@codemirror/lang-markdown';
import { languages } from '@codemirror/language-data';

const SthenoConfig = {
    extensions: [
        /*@__PURE__*/highlightSpecialChars(),
        /*@__PURE__*/history(),
        /*@__PURE__*/drawSelection(),
        /*@__PURE__*/dropCursor(),
        /*@__PURE__*/EditorState.allowMultipleSelections.of(true),
        /*@__PURE__*/indentOnInput(),
        /*@__PURE__*/syntaxHighlighting(defaultHighlightStyle, { fallback: true }),
        /*@__PURE__*/bracketMatching(),
        /*@__PURE__*/closeBrackets(),
        /*@__PURE__*/autocompletion(),
        /*@__PURE__*/highlightSelectionMatches(),
        EditorView.lineWrapping,
        /*@__PURE__*/keymap.of([
            ...closeBracketsKeymap,
            ...defaultKeymap,
            ...searchKeymap,
            ...historyKeymap,
            ...foldKeymap,
            ...completionKeymap,
            ...lintKeymap,
            indentWithTab,
        ]),
        /*@__PURE__*/markdown({ codeLanguages: languages, base: markdownLanguage })
    ],
};

export { SthenoConfig };
